Nonparametric estimator of the cumulative incidences of competing risks under double truncation. The estimator generalizes the Efron-Petrosian NPMLE (Non-Parametric Maximun Likelihood Estimator) to the competing risks setting.
<U+2018>DTDAcif<U+2019>
<U+2018>plot.DTDAcif<U+2019>
<U+2018>summary.DTDAcif<U+2019>
Jacobo de U<U+00F1>a-<U+00C1>lvarez was supported by Grant MTM2017-89422-P (MINECO/AEI/FEDER, UE).
Jos<U+00E9> Carlos Soage was supported by Grupos de Referencia Competitiva, Consolidaci<U+00F3>n y Estructuraci<U+00F3>n de Unidades de Investigaci<U+00F3>n Competitivas del SUG, Cons. de Cultura, Educaci<U+00F3>n e OU, Xunta de Galicia (GRC ED431C 2016/040).
Package: <U+2018>DTDA.cif<U+2019>
Version: 1.0.2
Maintainer: Jos<U+00E9> Carlos Soage Gonz<U+00E1>lez jsoage@uvigo.es
License: GPL-2
de U<U+00F1>a-<U+00C1>lvarez, J. (2019). Nonparametric estimation of the cumulative incidences of competing risks under double truncation. Preprint.
Efron, B. and Petrosian, V. (1999). Nonparametric methods for doubly truncated data. Journal of the American Statistical Association 94, 824-834.